Modify the physical position information of a data frame when converting genome build using executable liftOver.
snp_modifyBuild(
info_snp,
liftOver,
from = "hg18",
to = "hg19",
check_reverse = TRUE
)Input data frame info_snp with column "pos" in the new build.
A data frame with columns "chr" and "pos".
Path to liftOver executable. Binaries can be downloaded at https://hgdownload.cse.ucsc.edu/admin/exe/macOSX.x86_64/liftOver for Mac and at https://hgdownload.cse.ucsc.edu/admin/exe/linux.x86_64/liftOver for Linux.
Genome build to convert from. Default is hg18.
Genome build to convert to. Default is hg19.
Whether to discard positions for which we cannot go back
to initial values by doing 'from -> to -> from'. Default is TRUE.
Hinrichs, Angela S., et al. "The UCSC genome browser database: update 2006." Nucleic acids research 34.suppl_1 (2006): D590-D598.