powered by
A reference class for storing a pointer to a mapped version of a bed file.
bed(bedfile)
Path to file with extension ".bed" to read. You need the corresponding ".bim" and ".fam" in the same directory.
A bed object has many field:
bed
$address: address of the external pointer containing the underlying C++ object, to be used internally as a XPtr<bed> in C++ code
$address
XPtr<bed>
$extptr: use $address instead
$extptr
$bedfile: path to the bed file
$bedfile
$bimfile: path to the corresponding bim file
$bimfile
$famfile: path to the corresponding fam file
$famfile
$prefix: path without extension
$prefix
$nrow: number of samples in the bed file
$nrow
$ncol: number of variants in the bed file
$ncol
$map: data frame read from $bimfile
$map
$fam: data frame read from $famfile
$fam
$.map: use $map instead
$.map
$.fam: use $fam instead
$.fam
# NOT RUN { bedfile <- system.file("extdata", "example-missing.bed", package = "bigsnpr") (obj.bed <- bed(bedfile)) # }
Run the code above in your browser using DataLab